Sign up for a Free Mocavo Basic account

# Discovering Your Family History Should Be Easy

## Create a Free Account

× Sign up failure: Please email support@mocavo.com
Your Name

Please enter your name. We'd love to know what to call you.

E-Mail

Please provide an e-mail address so we can send you new discoveries and connections!

Password

Please enter a password to keep your account secure.

Please fill out all of the fields before signing up.

Please fill out all of the fields before submitting.

Have a Mocavo account? Sign in!

## Discover Your Story

- Explore over 6 billion historical names from one convenient place
- Collaborate and share with thousands of other family historians
- Upload and share historical family documents and photographs
- Stay updated on new record sets as we add them to our collection

## Benefits of Mocavo

Mocavo Basic is free and gives you access to all Mocavo content and sharing capabilities, such as sharing trees, documents and photos. Mocavo Search saves you the time and frustration associated with visiting and searching through multiple genealogy sites and irrelevant information. Now you can search across the Web from one convenient location, giving you access to information from genealogy libraries, state archives, and family records. You’ll make more discoveries, search more easily, and make valuable connections with the genealogy community.

## Upload Your Story with Mocavo

- ##

  ### Upload
  a Tree

- ##

  ### Upload
  a Document

- ##

  ### Upload
  a Database

## Upload Your Family Tree

- ##

  ### Upload
  from Desktop

## Upload a Document

- ##

  ### Upload
  from Desktop

### Select Family Tree File (Step 1 of 2)

Choose File from Your Computer

### Upload a Family Tree (Step 2 of 2)

Give this Tree a Name

### Upload a Document (Step 1 of 2)

Choose File

### Suggest a Site

We are always on the lookout for new resources to add to our database. If you have a website that you believe would benefit our community, please let us know.

Website URL (please provide a URL)
Your Email (please provide a valid email)
Brief Description (please provide a brief description)

### Upload a Database

We are always on the lookout for new records to add to our database. If you have a resource that you would like to contribute to our community, please let us know and we will be in touch as soon as possible.

Your Name Your E-Mail Please Describe Your Database Please Categorize Your Database